@@ -9,6 +9,27 @@
 #' @seealso [Boost Documentation](https://www.boost.org/doc/libs/latest/libs/math/doc/html/math_toolkit/dist_ref/dists/gamma_dist.html) for more details on the mathematical background.
 #' @examples
 #' # Gamma distribution with shape = 3, scale = 4
+#' dist <- gamma_distribution(3, 4)
+#' # Apply generic functions
+#' cdf(dist, 0.5)
+#' logcdf(dist, 0.5)
+#' pdf(dist, 0.5)
+#' logpdf(dist, 0.5)
+#' hazard(dist, 0.5)
+#' chf(dist, 0.5)
+#' mean(dist)
+#' median(dist)
+#' mode(dist)
+#' range(dist)
+#' quantile(dist, 0.2)
+#' standard_deviation(dist)
+#' support(dist)
+#' variance(dist)
+#' skewness(dist)
+#' kurtosis(dist)
+#' kurtosis_excess(dist)
+#'
+#' # Convenience functions
 #' gamma_pdf(2, 3, 4)
 #' gamma_lpdf(2, 3, 4)
 #' gamma_cdf(2, 3, 4)
@@ -18,30 +39,43 @@ NULL
 
 #' @rdname gamma_distribution
 #' @export
-gamma_pdf <- function(x, shape, scale) {
-  .Call(`gamma_pdf_`, x, shape, scale)
+gamma_distribution <- function(shape, scale = 1) {
+  structure(
+    list(
+      extptr = .Call(`gamma_init_`, shape, scale),
+      shape = shape,
+      scale = scale
+    ),
+    class = c("gamma_distribution", "boost_distribution")
+  )
 }
 
 #' @rdname gamma_distribution
 #' @export
-gamma_lpdf <- function(x, shape, scale) {
-  .Call(`gamma_logpdf_`, x, shape, scale)
+gamma_pdf <- function(x, shape, scale = 1) {
+  pdf(gamma_distribution(shape, scale), x)
 }
 
 #' @rdname gamma_distribution
 #' @export
-gamma_cdf <- function(x, shape, scale) {
-  .Call(`gamma_cdf_`, x, shape, scale)
+gamma_lpdf <- function(x, shape, scale = 1) {
+  logpdf(gamma_distribution(shape, scale), x)
 }
 
 #' @rdname gamma_distribution
 #' @export
-gamma_lcdf <- function(x, shape, scale) {
-  .Call(`gamma_logcdf_`, x, shape, scale)
+gamma_cdf <- function(x, shape, scale = 1) {
+  cdf(gamma_distribution(shape, scale), x)
 }
 
 #' @rdname gamma_distribution
 #' @export
-gamma_quantile <- function(p, shape, scale) {
-  .Call(`gamma_quantile_`, p, shape, scale)
+gamma_lcdf <- function(x, shape, scale = 1) {
+  logcdf(gamma_distribution(shape, scale), x)
+}
+
+#' @rdname gamma_distribution
+#' @export
+gamma_quantile <- function(p, shape, scale = 1) {
+  quantile(gamma_distribution(shape, scale), p)
 }
