@@ -1,15 +1,9 @@
 #ifndef BOOSTMATH_MACROS_HPP
 #define BOOSTMATH_MACROS_HPP
 
+#include <cpp11/declarations.hpp>
 #include "sexp.hpp"
 
-#define NOARG_BOOST_FUNCTION(name) \
-  extern "C" SEXP name##_() { \
-    BEGIN_CPP11 \
-    return boostmath::as_sexp(boost::math::name()); \
-    END_CPP11 \
-  }
-
 #define NOARG_BOOST_MEMBER(name) \
   extern "C" SEXP name##_() { \
     BEGIN_CPP11 \
@@ -24,13 +18,6 @@
     END_CPP11 \
   }
 
-#define NOARG_BOOST_FUNCTION_TYPE(name, template_type) \
-  extern "C" SEXP name##_() { \
-    BEGIN_CPP11 \
-    return boostmath::as_sexp(boost::math::name<template_type>()); \
-    END_CPP11 \
-  }
-
 #define UNARY_BOOST_FUNCTION(name, arg_type) \
   extern "C" SEXP name##_(SEXP x_) { \
     BEGIN_CPP11 \
