@@ -1,5 +1,3 @@
-#include <cpp11.hpp>
-#include <cpp11/declarations.hpp>
 #include <boost/math/tools/cubic_roots.hpp>
 #include <boost/math/tools/quartic_roots.hpp>
 #include <boost/math/tools/roots.hpp>
